/**
 * @license
 * Copyright 2023-2025 Dynatrace LLC
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

// packages/client/notification/src/lib/apis/self-notifications-api.ts
import {
  httpClient as defaultHttpClient,
  isHttpClientAbortError,
  isHttpClientResponseError
} from "@dynatrace-sdk/http-client";
import {
  ApiClientError,
  ClientRequestError as ClientRequestError2,
  InvalidResponseError,
  isInvalidResponseError
} from "@dynatrace-sdk/shared-errors";

// packages/client/notification/src/lib/error-envelopes/api-gateway-errors-handler.ts
import { ApiGatewayError } from "@dynatrace-sdk/shared-errors";
async function apiGatewayErrorsHandler(response) {
  if (response.headers?.["dynatrace-response-source"] === "API Gateway") {
    const responseBody = await response.body("json");
    throw new ApiGatewayError(response, responseBody);
  }
}

// packages/client/notification/src/lib/error-envelopes/error-envelope-error.ts
import { ClientRequestError } from "@dynatrace-sdk/shared-errors";
var ErrorEnvelopeError = class extends ClientRequestError {
  isErrorEnvelopeError = true;
};
function isErrorEnvelopeError(e) {
  return e?.isApiClientError === true && e?.isClientRequestError === true && e?.isErrorEnvelopeError === true && e instanceof Error;
}

// packages/client/notification/src/lib/error-envelopes/get-error-message.ts
function serializeData(data) {
  try {
    return JSON.stringify(data);
  } catch (e) {
    return String(data);
  }
}
function getMessagesFromErrorDetails(details) {
  const messages = [];
  Object.entries(details).forEach(([name, data]) => {
    if (!data)
      return;
    const serializedData = serializeData(data);
    switch (name) {
      case "missingScopes":
        messages.push(`Missing scopes: ${serializedData}`);
        break;
      default:
        messages.push(`${name}: ${serializedData}`);
    }
  }, []);
  return messages;
}
function getErrorMessage(errorBody, defaultMessage) {
  const error = errorBody;
  const msg = error?.error?.message || defaultMessage;
  const details = error?.error?.details || {};
  return [msg, ...getMessagesFromErrorDetails(details)].join(". ");
}

// packages/client/notification/src/lib/utils/transformations.ts
var defaultRuleConfig = {
  force: false,
  datetime: false
};
function mergeKeys(key1, key2) {
  if (!key1)
    return key2;
  if (!key2)
    return key1;
  return `${key1}.${key2}`;
}
function matchKey(key, keys) {
  const match = keys.find((k) => {
    const ruleKey = Array.isArray(k) ? k[0] : k;
    if (key === ruleKey) {
      return true;
    }
    if (!key || !ruleKey) {
      return false;
    }
    const [keyParts, ruleKeyParts] = [key.split("."), ruleKey.split(".")];
    const [keyPartsReversed, ruleKeyPartsReversed] = [[...keyParts].reverse(), [...ruleKeyParts].reverse()];
    let wildcard = false;
    let matchResult = true;
    keyParts.forEach((keyPart, idx) => {
      if (keyPart !== ruleKeyParts[idx] && !wildcard) {
        if (ruleKeyParts[idx] === "**") {
          wildcard = true;
        } else if (ruleKeyParts[idx] === "*") {
          wildcard = true;
        } else {
          matchResult = false;
        }
      }
    });
    wildcard = false;
    keyPartsReversed.forEach((keyPart, idx) => {
      if (keyPart !== ruleKeyPartsReversed[idx] && !wildcard) {
        if (ruleKeyPartsReversed[idx] === "**") {
          wildcard = true;
        } else if (ruleKeyPartsReversed[idx] === "*") {
          wildcard = true;
        } else {
          matchResult = false;
        }
      }
    });
    return matchResult;
  });
  if (match) {
    return Array.isArray(match) ? match : [match, defaultRuleConfig];
  }
  return null;
}
var potentialMatchForRoot = (pattern, key) => pattern.startsWith(key) || pattern.startsWith("*") || pattern.startsWith("**");
var potentialMatch = (pattern, key) => pattern.startsWith(key) || pattern.includes("*") || pattern.includes("**");
function partialMatch(key, keyPatterns) {
  if (key.includes(".")) {
    const keyParts = key.split(".");
    let currentKey = "";
    return !!keyParts.find((keyPart) => {
      currentKey = mergeKeys(currentKey, keyPart);
      const isRoot = !currentKey.includes(".");
      if (isRoot) {
        return !!keyPatterns.find((k) => potentialMatchForRoot(k, currentKey));
      }
      return !!keyPatterns.find((k) => potentialMatch(k, currentKey));
    });
  }
  return !!keyPatterns.find((k) => potentialMatchForRoot(k, key));
}
var dateTimePattern = /^((?:(\d{4}-\d{2}-\d{2})T(\d{2}:\d{2}:\d{2}(?:\.\d+)?))(Z|[+-]\d{2}:\d{2})?)$/i;
function isDateLike(value) {
  if (typeof value === "string") {
    return dateTimePattern.test(value);
  }
  return false;
}
function transformValue(value, rules, direction) {
  const { force, datetime } = rules;
  if (direction === "to") {
    return force || isDateLike(value) ? new Date(value) : value;
  }
  if (value instanceof Date) {
    const iso = value.toISOString();
    return datetime ? iso : iso.split("T")[0];
  }
  return value;
}
function walk(obj, direction, keyPatterns, flatKeyPatterns, currentKey = "") {
  if (keyPatterns.length <= 0) {
    return obj;
  }
  if (!partialMatch(currentKey, flatKeyPatterns)) {
    return obj;
  }
  if (Array.isArray(obj)) {
    obj.forEach((item, idx) => {
      if (typeof item === "object" && item !== null) {
        walk(item, direction, keyPatterns, flatKeyPatterns, currentKey);
      } else {
        const match = matchKey(currentKey, keyPatterns);
        if (match) {
          obj[idx] = transformValue(obj[idx], match[1], direction);
        }
      }
    });
  }
  if (typeof obj === "object" && obj !== null && !Array.isArray(obj)) {
    for (const key of Object.keys(obj)) {
      const mergedKey = mergeKeys(currentKey, key);
      const match = matchKey(mergedKey, keyPatterns);
      if (match) {
        obj[key] = transformValue(obj[key], match[1], direction);
      }
      walk(obj[key], direction, keyPatterns, flatKeyPatterns, mergedKey);
    }
  }
  return obj;
}
function flattenKeys(keys) {
  return keys.map((k) => Array.isArray(k) ? k[0] : k);
}
function transform(direction, object, keys) {
  const flatKeys = flattenKeys(keys);
  return walk(object, direction, keys, flatKeys);
}
function transformRequest(object, keys) {
  return transform("from", object, keys);
}
function transformResponse(object, keys) {
  return transform("to", object, keys);
}

// packages/client/notification/src/lib/utils/url-helpers.ts
var encodeQueryParam = (key, value) => {
  const encodedKey = encodeURIComponent(key);
  return `${encodedKey}=${encodeURIComponent(typeof value === "number" ? value : String(value))}`;
};
var addExplodedArrayQueryParam = (query, key) => {
  const arrayValue = query[key];
  return arrayValue.map((value) => encodeQueryParam(key, value)).join("&");
};
var addNonExplodedArrayQueryParams = (query, key) => {
  const encodedKey = encodeURIComponent(key);
  const encodedParamsList = query[key].map((value) => encodeURIComponent(typeof value === "number" ? value : String(value))).join(",");
  return `${encodedKey}=${encodedParamsList}`;
};
var addQueryParam = (query, key) => encodeQueryParam(key, query[key]);
var arrayQueryParams = (query, key, explode) => {
  return explode ? addExplodedArrayQueryParam(query, key) : addNonExplodedArrayQueryParams(query, key);
};
var toQueryString = (rawQuery, flags = {}) => {
  const query = rawQuery || {};
  const keys = Object.keys(query).filter((key) => typeof query[key] !== "undefined");
  const queryString = keys.map(
    (key) => Array.isArray(query[key]) ? arrayQueryParams(query, key, flags.explode?.hasOwnProperty(key) ? flags.explode[key] : true) : addQueryParam(query, key)
  ).join("&");
  return queryString ? `?${queryString}` : "";
};

// packages/client/notification/src/lib/apis/self-notifications-api.ts
var SelfNotificationsClient = class {
  httpClient;
  shouldTransformDates = true;
  /**
   * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a SelfNotificationsClient. Custom http client should implement {HttpClient} interface.
   * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
   * @example
   * const selfNotificationsClientNodeJs = new SelfNotificationsClient(yourCustomImplementation);
   */
  constructor(httpClientImplementation, options) {
    this.httpClient = httpClientImplementation;
    this.shouldTransformDates = options?.transformDates ?? true;
  }
  /**
   * **Required scope:** notification:self-notifications:read
   *
   * @returns {Promise<PaginatedSelfNotificationList>}
   *
   * @example <caption>Code example</caption>
   * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
   *
   * const data =
   *   await selfNotificationsClient.getSelfNotifications();
   *
   * @throws {ErrorEnvelopeError}
   * @throws {InvalidResponseError}
   * @throws {ApiClientError}
   * @throws {ClientRequestError}
   */
  async getSelfNotifications(config = {}) {
    if (!config) {
      throw new ApiClientError("API client error", "API client call is missing mandatory config parameter");
    }
    const query = toQueryString({
      appId: config.appId,
      limit: config.limit,
      notificationType: config.notificationType,
      offset: config.offset,
      ordering: config.ordering,
      owner: config.owner,
      resourceId: config.resourceId,
      search: config.search
    });
    try {
      const response = await this.httpClient.send({
        url: `/platform/notification/v1/self-notifications${query}`,
        method: "GET",
        headers: {
          Accept: "application/json"
        },
        abortSignal: config instanceof EventTarget ? config : config.abortSignal,
        statusValidator: (status) => {
          return [200].includes(status);
        }
      });
      const responseValue = await response.body("json");
      try {
        return this.shouldTransformDates ? transformResponse(responseValue, [
          ["results.modificationInfo.createdTime", { datetime: true }],
          ["results.modificationInfo.lastModifiedTime", { datetime: true }]
        ]) : responseValue;
      } catch (err) {
        throw new InvalidResponseError(
          `SelfNotificationsClient.getSelfNotifications:200`,
          err,
          responseValue,
          void 0,
          void 0,
          response
        );
      }
    } catch (e) {
      if (isHttpClientAbortError(e) || isInvalidResponseError(e)) {
        throw e;
      }
      if (!isHttpClientResponseError(e)) {
        throw new ApiClientError("UnexpectedError", "Unexpected error", e);
      }
      const response = e.response;
      await apiGatewayErrorsHandler(response);
      if (response.status >= 400 && response.status <= 499) {
        const responseValue = await response.body("json");
        try {
          const errorBody = this.shouldTransformDates ? transformResponse(responseValue, []) : responseValue;
          throw new ErrorEnvelopeError(`${response.status}`, response, errorBody, getErrorMessage(errorBody, ""), e);
        } catch (err) {
          if (err instanceof ErrorEnvelopeError) {
            throw err;
          }
          throw new InvalidResponseError(
            `SelfNotificationsClient.getSelfNotifications:${response.status}`,
            err,
            responseValue,
            "ErrorEnvelope",
            void 0,
            response
          );
        }
      } else {
        try {
          const responseValue = await response.body("json");
          throw new ClientRequestError2(
            `${response.status}`,
            response,
            responseValue,
            getErrorMessage(responseValue, `Unexpected api response: code=${response.status} body="${responseValue}"`)
          );
        } catch (error) {
          if (error instanceof ClientRequestError2) {
            throw error;
          }
          const responseValue = await response.body("text").catch(() => "");
          throw new InvalidResponseError(
            `${response.status}`,
            error,
            responseValue,
            "json",
            "Unexpected api response",
            response
          );
        }
      }
    }
  }
  /**
   * **Required scope:** notification:self-notifications:write
   *
   * @returns {Promise<SelfNotification>}
   *
   * @example <caption>Code example</caption>
   * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
   *
   * const data =
   *   await selfNotificationsClient.createSelfNotification({
   *     body: {
   *       resourceId: "...",
   *       notificationType: "...",
   *       triggerConfiguration: {
   *         type: EventQueryTriggerConfigType.Event,
   *         value: { query: "..." },
   *       },
   *     },
   *   });
   *
   * @throws {ErrorEnvelopeError}
   * @throws {InvalidResponseError}
   * @throws {ApiClientError}
   * @throws {ClientRequestError}
   */
  async createSelfNotification(config) {
    if (!config) {
      throw new ApiClientError("API client error", "API client call is missing mandatory config parameter");
    }
    const encodedBody = this.shouldTransformDates ? transformRequest(config.body, []) : config.body;
    try {
      const response = await this.httpClient.send({
        url: `/platform/notification/v1/self-notifications`,
        method: "POST",
        requestBodyType: "json",
        body: encodedBody,
        headers: {
          "Content-Type": "application/json",
          Accept: "application/json"
        },
        abortSignal: config instanceof EventTarget ? config : config.abortSignal,
        statusValidator: (status) => {
          return [201].includes(status);
        }
      });
      const responseValue = await response.body("json");
      try {
        return this.shouldTransformDates ? transformResponse(responseValue, [
          ["modificationInfo.createdTime", { datetime: true }],
          ["modificationInfo.lastModifiedTime", { datetime: true }]
        ]) : responseValue;
      } catch (err) {
        throw new InvalidResponseError(
          `SelfNotificationsClient.createSelfNotification:201`,
          err,
          responseValue,
          void 0,
          void 0,
          response
        );
      }
    } catch (e) {
      if (isHttpClientAbortError(e) || isInvalidResponseError(e)) {
        throw e;
      }
      if (!isHttpClientResponseError(e)) {
        throw new ApiClientError("UnexpectedError", "Unexpected error", e);
      }
      const response = e.response;
      await apiGatewayErrorsHandler(response);
      if (response.status >= 400 && response.status <= 499) {
        const responseValue = await response.body("json");
        try {
          const errorBody = this.shouldTransformDates ? transformResponse(responseValue, []) : responseValue;
          throw new ErrorEnvelopeError(`${response.status}`, response, errorBody, getErrorMessage(errorBody, ""), e);
        } catch (err) {
          if (err instanceof ErrorEnvelopeError) {
            throw err;
          }
          throw new InvalidResponseError(
            `SelfNotificationsClient.createSelfNotification:${response.status}`,
            err,
            responseValue,
            "ErrorEnvelope",
            void 0,
            response
          );
        }
      } else {
        try {
          const responseValue = await response.body("json");
          throw new ClientRequestError2(
            `${response.status}`,
            response,
            responseValue,
            getErrorMessage(responseValue, `Unexpected api response: code=${response.status} body="${responseValue}"`)
          );
        } catch (error) {
          if (error instanceof ClientRequestError2) {
            throw error;
          }
          const responseValue = await response.body("text").catch(() => "");
          throw new InvalidResponseError(
            `${response.status}`,
            error,
            responseValue,
            "json",
            "Unexpected api response",
            response
          );
        }
      }
    }
  }
  /**
   * **Required scope:** notification:self-notifications:read
   *
   * @returns {Promise<SelfNotification>}
   *
   * @example <caption>Code example</caption>
   * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
   *
   * const data =
   *   await selfNotificationsClient.getSelfNotification({
   *     id: "...",
   *   });
   *
   * @throws {ErrorEnvelopeError}
   * @throws {InvalidResponseError}
   * @throws {ApiClientError}
   * @throws {ClientRequestError}
   */
  async getSelfNotification(config) {
    try {
      const response = await this.httpClient.send({
        url: `/platform/notification/v1/self-notifications/${config.id}`,
        method: "GET",
        headers: {
          Accept: "application/json"
        },
        abortSignal: config instanceof EventTarget ? config : config.abortSignal,
        statusValidator: (status) => {
          return [200].includes(status);
        }
      });
      const responseValue = await response.body("json");
      try {
        return this.shouldTransformDates ? transformResponse(responseValue, [
          ["modificationInfo.createdTime", { datetime: true }],
          ["modificationInfo.lastModifiedTime", { datetime: true }]
        ]) : responseValue;
      } catch (err) {
        throw new InvalidResponseError(
          `SelfNotificationsClient.getSelfNotification:200`,
          err,
          responseValue,
          void 0,
          void 0,
          response
        );
      }
    } catch (e) {
      if (isHttpClientAbortError(e) || isInvalidResponseError(e)) {
        throw e;
      }
      if (!isHttpClientResponseError(e)) {
        throw new ApiClientError("UnexpectedError", "Unexpected error", e);
      }
      const response = e.response;
      await apiGatewayErrorsHandler(response);
      if (response.status >= 400 && response.status <= 499) {
        const responseValue = await response.body("json");
        try {
          const errorBody = this.shouldTransformDates ? transformResponse(responseValue, []) : responseValue;
          throw new ErrorEnvelopeError(`${response.status}`, response, errorBody, getErrorMessage(errorBody, ""), e);
        } catch (err) {
          if (err instanceof ErrorEnvelopeError) {
            throw err;
          }
          throw new InvalidResponseError(
            `SelfNotificationsClient.getSelfNotification:${response.status}`,
            err,
            responseValue,
            "ErrorEnvelope",
            void 0,
            response
          );
        }
      } else {
        try {
          const responseValue = await response.body("json");
          throw new ClientRequestError2(
            `${response.status}`,
            response,
            responseValue,
            getErrorMessage(responseValue, `Unexpected api response: code=${response.status} body="${responseValue}"`)
          );
        } catch (error) {
          if (error instanceof ClientRequestError2) {
            throw error;
          }
          const responseValue = await response.body("text").catch(() => "");
          throw new InvalidResponseError(
            `${response.status}`,
            error,
            responseValue,
            "json",
            "Unexpected api response",
            response
          );
        }
      }
    }
  }
  /**
   * **Required scope:** notification:self-notifications:write
   *
   * @returns {Promise<SelfNotification>}
   *
   * @example <caption>Code example</caption>
   * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
   *
   * const data =
   *   await selfNotificationsClient.updateSelfNotification({
   *     id: "...",
   *     body: {
   *       triggerConfiguration: {
   *         type: EventQueryTriggerConfigType.Event,
   *         value: { query: "..." },
   *       },
   *     },
   *   });
   *
   * @throws {ErrorEnvelopeError}
   * @throws {InvalidResponseError}
   * @throws {ApiClientError}
   * @throws {ClientRequestError}
   */
  async updateSelfNotification(config) {
    if (!config) {
      throw new ApiClientError("API client error", "API client call is missing mandatory config parameter");
    }
    const encodedBody = this.shouldTransformDates ? transformRequest(config.body, []) : config.body;
    try {
      const response = await this.httpClient.send({
        url: `/platform/notification/v1/self-notifications/${config.id}`,
        method: "PUT",
        requestBodyType: "json",
        body: encodedBody,
        headers: {
          "Content-Type": "application/json",
          Accept: "application/json"
        },
        abortSignal: config instanceof EventTarget ? config : config.abortSignal,
        statusValidator: (status) => {
          return [200].includes(status);
        }
      });
      const responseValue = await response.body("json");
      try {
        return this.shouldTransformDates ? transformResponse(responseValue, [
          ["modificationInfo.createdTime", { datetime: true }],
          ["modificationInfo.lastModifiedTime", { datetime: true }]
        ]) : responseValue;
      } catch (err) {
        throw new InvalidResponseError(
          `SelfNotificationsClient.updateSelfNotification:200`,
          err,
          responseValue,
          void 0,
          void 0,
          response
        );
      }
    } catch (e) {
      if (isHttpClientAbortError(e) || isInvalidResponseError(e)) {
        throw e;
      }
      if (!isHttpClientResponseError(e)) {
        throw new ApiClientError("UnexpectedError", "Unexpected error", e);
      }
      const response = e.response;
      await apiGatewayErrorsHandler(response);
      if (response.status >= 400 && response.status <= 499) {
        const responseValue = await response.body("json");
        try {
          const errorBody = this.shouldTransformDates ? transformResponse(responseValue, []) : responseValue;
          throw new ErrorEnvelopeError(`${response.status}`, response, errorBody, getErrorMessage(errorBody, ""), e);
        } catch (err) {
          if (err instanceof ErrorEnvelopeError) {
            throw err;
          }
          throw new InvalidResponseError(
            `SelfNotificationsClient.updateSelfNotification:${response.status}`,
            err,
            responseValue,
            "ErrorEnvelope",
            void 0,
            response
          );
        }
      } else {
        try {
          const responseValue = await response.body("json");
          throw new ClientRequestError2(
            `${response.status}`,
            response,
            responseValue,
            getErrorMessage(responseValue, `Unexpected api response: code=${response.status} body="${responseValue}"`)
          );
        } catch (error) {
          if (error instanceof ClientRequestError2) {
            throw error;
          }
          const responseValue = await response.body("text").catch(() => "");
          throw new InvalidResponseError(
            `${response.status}`,
            error,
            responseValue,
            "json",
            "Unexpected api response",
            response
          );
        }
      }
    }
  }
  /**
   * **Required scope:** notification:self-notifications:write
   *
   * @example <caption>Code example</caption>
   * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
   *
   * const data =
   *   await selfNotificationsClient.deleteSelfNotification({
   *     id: "...",
   *   });
   *
   * @throws {ErrorEnvelopeError}
   * @throws {InvalidResponseError}
   * @throws {ApiClientError}
   * @throws {ClientRequestError}
   */
  async deleteSelfNotification(config) {
    try {
      await this.httpClient.send({
        url: `/platform/notification/v1/self-notifications/${config.id}`,
        method: "DELETE",
        abortSignal: config instanceof EventTarget ? config : config.abortSignal,
        statusValidator: (status) => {
          return [204].includes(status);
        }
      });
      return;
    } catch (e) {
      if (isHttpClientAbortError(e)) {
        throw e;
      }
      if (!isHttpClientResponseError(e)) {
        throw new ApiClientError("UnexpectedError", "Unexpected error", e);
      }
      const response = e.response;
      await apiGatewayErrorsHandler(response);
      if (response.status >= 400 && response.status <= 499) {
        const responseValue = await response.body("json");
        try {
          const errorBody = this.shouldTransformDates ? transformResponse(responseValue, []) : responseValue;
          throw new ErrorEnvelopeError(`${response.status}`, response, errorBody, getErrorMessage(errorBody, ""), e);
        } catch (err) {
          if (err instanceof ErrorEnvelopeError) {
            throw err;
          }
          throw new InvalidResponseError(
            `SelfNotificationsClient.deleteSelfNotification:${response.status}`,
            err,
            responseValue,
            "ErrorEnvelope",
            void 0,
            response
          );
        }
      } else {
        try {
          const responseValue = await response.body("json");
          throw new ClientRequestError2(
            `${response.status}`,
            response,
            responseValue,
            getErrorMessage(responseValue, `Unexpected api response: code=${response.status} body="${responseValue}"`)
          );
        } catch (error) {
          if (error instanceof ClientRequestError2) {
            throw error;
          }
          const responseValue = await response.body("text").catch(() => "");
          throw new InvalidResponseError(
            `${response.status}`,
            error,
            responseValue,
            "json",
            "Unexpected api response",
            response
          );
        }
      }
    }
  }
  /**
   * **Required scope:** notification:self-notifications:write
   *
   * @returns {Promise<SelfNotification>}
   *
   * @example <caption>Code example</caption>
   * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
   *
   * const data =
   *   await selfNotificationsClient.patchSelfNotification({
   *     id: "...",
   *     body: {
   *       triggerConfiguration: {
   *         type: EventQueryTriggerConfigType.Event,
   *         value: { query: "..." },
   *       },
   *     },
   *   });
   *
   * @throws {ErrorEnvelopeError}
   * @throws {InvalidResponseError}
   * @throws {ApiClientError}
   * @throws {ClientRequestError}
   */
  async patchSelfNotification(config) {
    if (!config) {
      throw new ApiClientError("API client error", "API client call is missing mandatory config parameter");
    }
    const encodedBody = this.shouldTransformDates ? transformRequest(config.body, []) : config.body;
    try {
      const response = await this.httpClient.send({
        url: `/platform/notification/v1/self-notifications/${config.id}`,
        method: "PATCH",
        requestBodyType: "json",
        body: encodedBody,
        headers: {
          "Content-Type": "application/json",
          Accept: "application/json"
        },
        abortSignal: config instanceof EventTarget ? config : config.abortSignal,
        statusValidator: (status) => {
          return [200].includes(status);
        }
      });
      const responseValue = await response.body("json");
      try {
        return this.shouldTransformDates ? transformResponse(responseValue, [
          ["modificationInfo.createdTime", { datetime: true }],
          ["modificationInfo.lastModifiedTime", { datetime: true }]
        ]) : responseValue;
      } catch (err) {
        throw new InvalidResponseError(
          `SelfNotificationsClient.patchSelfNotification:200`,
          err,
          responseValue,
          void 0,
          void 0,
          response
        );
      }
    } catch (e) {
      if (isHttpClientAbortError(e) || isInvalidResponseError(e)) {
        throw e;
      }
      if (!isHttpClientResponseError(e)) {
        throw new ApiClientError("UnexpectedError", "Unexpected error", e);
      }
      const response = e.response;
      await apiGatewayErrorsHandler(response);
      if (response.status >= 400 && response.status <= 499) {
        const responseValue = await response.body("json");
        try {
          const errorBody = this.shouldTransformDates ? transformResponse(responseValue, []) : responseValue;
          throw new ErrorEnvelopeError(`${response.status}`, response, errorBody, getErrorMessage(errorBody, ""), e);
        } catch (err) {
          if (err instanceof ErrorEnvelopeError) {
            throw err;
          }
          throw new InvalidResponseError(
            `SelfNotificationsClient.patchSelfNotification:${response.status}`,
            err,
            responseValue,
            "ErrorEnvelope",
            void 0,
            response
          );
        }
      } else {
        try {
          const responseValue = await response.body("json");
          throw new ClientRequestError2(
            `${response.status}`,
            response,
            responseValue,
            getErrorMessage(responseValue, `Unexpected api response: code=${response.status} body="${responseValue}"`)
          );
        } catch (error) {
          if (error instanceof ClientRequestError2) {
            throw error;
          }
          const responseValue = await response.body("text").catch(() => "");
          throw new InvalidResponseError(
            `${response.status}`,
            error,
            responseValue,
            "json",
            "Unexpected api response",
            response
          );
        }
      }
    }
  }
};
var selfNotificationsClient = /* @__PURE__ */ new SelfNotificationsClient(defaultHttpClient);

// packages/client/notification/src/lib/error-envelopes/index.ts
import {
  ApiClientError as ApiClientError2,
  ApiGatewayError as ApiGatewayError2,
  ClientRequestError as ClientRequestError3,
  InvalidResponseError as InvalidResponseError2,
  isApiClientError,
  isApiGatewayError,
  isClientRequestError,
  isInvalidResponseError as isInvalidResponseError2
} from "@dynatrace-sdk/shared-errors";

// packages/client/notification/src/lib/models/davis-event-name-match.ts
var DavisEventNameMatch = /* @__PURE__ */ ((DavisEventNameMatch2) => {
  DavisEventNameMatch2["Equals"] = "equals";
  DavisEventNameMatch2["Contains"] = "contains";
  return DavisEventNameMatch2;
})(DavisEventNameMatch || {});

// packages/client/notification/src/lib/models/davis-event-trigger-config-type.ts
var DavisEventTriggerConfigType = /* @__PURE__ */ ((DavisEventTriggerConfigType2) => {
  DavisEventTriggerConfigType2["DavisEvent"] = "davis-event";
  return DavisEventTriggerConfigType2;
})(DavisEventTriggerConfigType || {});

// packages/client/notification/src/lib/models/davis-problem-trigger-config-type.ts
var DavisProblemTriggerConfigType = /* @__PURE__ */ ((DavisProblemTriggerConfigType2) => {
  DavisProblemTriggerConfigType2["DavisProblem"] = "davis-problem";
  return DavisProblemTriggerConfigType2;
})(DavisProblemTriggerConfigType || {});

// packages/client/notification/src/lib/models/entity-tags-match.ts
var EntityTagsMatch = /* @__PURE__ */ ((EntityTagsMatch2) => {
  EntityTagsMatch2["All"] = "all";
  EntityTagsMatch2["Any"] = "any";
  return EntityTagsMatch2;
})(EntityTagsMatch || {});

// packages/client/notification/src/lib/models/event-query-trigger-config-type.ts
var EventQueryTriggerConfigType = /* @__PURE__ */ ((EventQueryTriggerConfigType2) => {
  EventQueryTriggerConfigType2["Event"] = "event";
  return EventQueryTriggerConfigType2;
})(EventQueryTriggerConfigType || {});

// packages/client/notification/src/lib/models/event-type.ts
var EventType = /* @__PURE__ */ ((EventType2) => {
  EventType2["Events"] = "events";
  EventType2["Bizevents"] = "bizevents";
  EventType2["DtSystemEvents"] = "dt.system.events";
  return EventType2;
})(EventType || {});
export {
  ApiClientError2 as ApiClientError,
  ApiGatewayError2 as ApiGatewayError,
  ClientRequestError3 as ClientRequestError,
  DavisEventNameMatch,
  DavisEventTriggerConfigType,
  DavisProblemTriggerConfigType,
  EntityTagsMatch,
  ErrorEnvelopeError,
  EventQueryTriggerConfigType,
  EventType,
  InvalidResponseError2 as InvalidResponseError,
  SelfNotificationsClient,
  isApiClientError,
  isApiGatewayError,
  isClientRequestError,
  isErrorEnvelopeError,
  isInvalidResponseError2 as isInvalidResponseError,
  selfNotificationsClient
};
