import { AbortSignal, HttpClient } from '@dynatrace-sdk/http-client';
import { PaginatedSelfNotificationList } from '../models/paginated-self-notification-list';
import { SelfNotification } from '../models/self-notification';
import { SelfNotificationCreate } from '../models/self-notification-create';
import { SelfNotificationUpdate } from '../models/self-notification-update';
import { ApiClientOptions } from './api-client-options';
export declare class SelfNotificationsClient {
    private httpClient;
    private shouldTransformDates;
    /**
     * @param {HttpClient} httpClientImplementation - You can provide custom http client as a parameter to constructor of a SelfNotificationsClient. Custom http client should implement {HttpClient} interface.
     * @param {ApiClientOptions} [options] - Optional configuration for SDK Client.
     * @example
     * const selfNotificationsClientNodeJs = new SelfNotificationsClient(yourCustomImplementation);
     */
    constructor(httpClientImplementation: HttpClient, options?: ApiClientOptions);
    /**
     * **Required scope:** notification:self-notifications:read
     *
     * @returns {Promise<PaginatedSelfNotificationList>}
     *
     * @example <caption>Code example</caption>
     * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
     *
     * const data =
     *   await selfNotificationsClient.getSelfNotifications();
     *
     * @throws {ErrorEnvelopeError}
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getSelfNotifications(config?: {
        appId?: string;
        /** Number of results to return per page. */ limit?: number;
        notificationType?: string;
        /** The initial index from which to return the results. */ offset?: number;
        /** Which field to use when ordering the results. */ ordering?: string;
        owner?: string;
        resourceId?: string;
        /** A search term. */ search?: string;
        abortSignal?: AbortSignal;
    }): Promise<PaginatedSelfNotificationList>;
    /**
     * **Required scope:** notification:self-notifications:write
     *
     * @returns {Promise<SelfNotification>}
     *
     * @example <caption>Code example</caption>
     * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
     *
     * const data =
     *   await selfNotificationsClient.createSelfNotification({
     *     body: {
     *       resourceId: "...",
     *       notificationType: "...",
     *       triggerConfiguration: {
     *         type: EventQueryTriggerConfigType.Event,
     *         value: { query: "..." },
     *       },
     *     },
     *   });
     *
     * @throws {ErrorEnvelopeError}
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    createSelfNotification(config: {
        body: SelfNotificationCreate;
        abortSignal?: AbortSignal;
    }): Promise<SelfNotification>;
    /**
     * **Required scope:** notification:self-notifications:read
     *
     * @returns {Promise<SelfNotification>}
     *
     * @example <caption>Code example</caption>
     * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
     *
     * const data =
     *   await selfNotificationsClient.getSelfNotification({
     *     id: "...",
     *   });
     *
     * @throws {ErrorEnvelopeError}
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    getSelfNotification(config: {
        /** A UUID string identifying this self notification. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<SelfNotification>;
    /**
     * **Required scope:** notification:self-notifications:write
     *
     * @returns {Promise<SelfNotification>}
     *
     * @example <caption>Code example</caption>
     * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
     *
     * const data =
     *   await selfNotificationsClient.updateSelfNotification({
     *     id: "...",
     *     body: {
     *       triggerConfiguration: {
     *         type: EventQueryTriggerConfigType.Event,
     *         value: { query: "..." },
     *       },
     *     },
     *   });
     *
     * @throws {ErrorEnvelopeError}
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    updateSelfNotification(config: {
        body: SelfNotificationUpdate;
        /** A UUID string identifying this self notification. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<SelfNotification>;
    /**
     * **Required scope:** notification:self-notifications:write
     *
     * @example <caption>Code example</caption>
     * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
     *
     * const data =
     *   await selfNotificationsClient.deleteSelfNotification({
     *     id: "...",
     *   });
     *
     * @throws {ErrorEnvelopeError}
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    deleteSelfNotification(config: {
        /** A UUID string identifying this self notification. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<void>;
    /**
     * **Required scope:** notification:self-notifications:write
     *
     * @returns {Promise<SelfNotification>}
     *
     * @example <caption>Code example</caption>
     * import { selfNotificationsClient } from "@dynatrace-sdk/client-notification";
     *
     * const data =
     *   await selfNotificationsClient.patchSelfNotification({
     *     id: "...",
     *     body: {
     *       triggerConfiguration: {
     *         type: EventQueryTriggerConfigType.Event,
     *         value: { query: "..." },
     *       },
     *     },
     *   });
     *
     * @throws {ErrorEnvelopeError}
     * @throws {InvalidResponseError}
     * @throws {ApiClientError}
     * @throws {ClientRequestError}
     */
    patchSelfNotification(config: {
        body: SelfNotificationUpdate;
        /** A UUID string identifying this self notification. */ id: string;
        abortSignal?: AbortSignal;
    }): Promise<SelfNotification>;
}
export declare const selfNotificationsClient: SelfNotificationsClient;
